@@ -18,14 +18,14 @@ import logging
 import webob.dec
 import webob.exc
 
+from oslo_middleware._i18n import _LE
 from oslo_middleware import base
-from oslo_middleware.i18n import _LE
 
 
 LOG = logging.getLogger(__name__)
 
 
-class CatchErrors(base.Middleware):
+class CatchErrors(base.ConfigurableMiddleware):
     """Middleware that provides high-level error handling.
 
     It catches all exceptions from subsequent applications in WSGI pipeline
